@@ -4,6 +4,8 @@ import pandas as pd
 import duckdb
 import io
 
+from chipmunkdb.ChipmunkDb import ChipmunkDb
+
 category_idx = pd.Index(['A', 'B'])
 date_idx = pd.date_range('2018-01', '2018-02', freq='MS')
 idx = pd.MultiIndex.from_product([category_idx, date_idx], names=['category', 'date'])
@@ -13,11 +15,12 @@ series = pd.Series(np.random.randn(len(category_idx) * len(date_idx)), index=idx
 
 df = pd.DataFrame(series)
 
-print(df)
-con = duckdb.connect(database='multiindex.duck', read_only=False)
+cdb = ChipmunkDb("localhost", 8091)
 
-con.register("my_view", df)
+#cdb.save_as_pandas(df, "test3")
+#cdb.save_collection("test3")
 
-con.execute("SELECT * FROM my_view")
+df2 = cdb.collection_as_pandas("test3")
+
+print(df2)
 
-print(con.fetchall())
\ No newline at end of file
